@@ -18,4 +18,6 @@ class User(Document):
 
     required_fields = ['application_id', 'name']
 
-    indexes = [{'fields': ['application_id']}]
+    indexes = [{'fields': ['application_id']},
+               {'fields': ['name'], 'unique': True},
+               ]
