@@ -90,3 +90,10 @@ class TestCollectionView(TestExampleController):
 
     def test_delete(self):
         pass
+
+    def test_create_conflict(self):
+        result = self.app.post(
+            '/applications/%s/users' % self.app_id,
+            {u'name': u'Bob Marley', }
+            )
+        print result
